@@ -2,11 +2,11 @@ import logging
 
 
 def setup_test_logging():
-    print('Setting up variety logger')
-    logger = logging.getLogger('variety')
+    print("Setting up variety logger")
+    logger = logging.getLogger("variety")
     logger.setLevel(logging.DEBUG)
     ch = logging.StreamHandler()
     ch.setLevel(logging.DEBUG)
-    formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
+    formatter = logging.Formatter("%(asctime)s - %(name)s - %(levelname)s - %(message)s")
     ch.setFormatter(formatter)
     logger.addHandler(ch)
