@@ -16,34 +16,39 @@
 
 """Code to add AppIndicator."""
 
-from gi.repository import Gtk # pylint: disable=E0611
+import logging
 import os
-import threading
 
-from variety.Smart import Smart
-from variety.Util import Util
+from gi.repository import Gtk  # pylint: disable=E0611
+
+from variety.Util import Util, _
+from variety_lib import varietyconfig
 
 THEME_ICON_NAME = "variety-indicator"
 THEME_ICON_NAME_DARK = "variety-indicator-dark"
+THEME_ICON_NAME_NUM = "variety-indicator-num{}"
 
 try:
     import gi
+
     try:
-        gi.require_version('AyatanaAppIndicator3', '0.1')
-        from gi.repository import AyatanaAppIndicator3 as AppIndicator3 # pylint: disable=E0611
+        gi.require_version("AyatanaAppIndicator3", "0.1")
+        from gi.repository import AyatanaAppIndicator3 as AppIndicator3  # pylint: disable=E0611
+
+        _indicator_backend = "AyatanaAppIndicator3"  # Just a dummy value we use for logging
     except (ValueError, ImportError):
-        gi.require_version('AppIndicator3', '0.1')
-        from gi.repository import AppIndicator3 # pylint: disable=E0611
+        gi.require_version("AppIndicator3", "0.1")
+        from gi.repository import AppIndicator3  # pylint: disable=E0611
+
+        _indicator_backend = "AppIndicator3"
     use_appindicator = True
 except (ValueError, ImportError):
+    _indicator_backend = "fallback tray"
     use_appindicator = False
 
-from variety_lib import varietyconfig
 
-from variety import _, _u
+logger = logging.getLogger("variety")
 
-import logging
-logger = logging.getLogger('variety')
 
 class Indicator:
     def __init__(self, window):
@@ -104,7 +109,7 @@ class Indicator:
 
         self.next = Gtk.MenuItem(_("_Next"))
         self.next.set_use_underline(True)
-        self.next.connect("activate", window.next_wallpaper)
+        self.next.connect("activate", window.next_image_same_quote)
         self.image_menu.append(self.next)
 
         self.prev = Gtk.MenuItem(_("_Previous"))
@@ -114,8 +119,10 @@ class Indicator:
 
         self.fast_forward = Gtk.MenuItem(_("_Next, skipping forward history"))
         self.fast_forward.set_use_underline(True)
+
         def _fast_forward(widget):
             window.next_wallpaper(widget, bypass_history=True)
+
         self.fast_forward.connect("activate", _fast_forward)
         self.image_menu.append(self.fast_forward)
 
@@ -144,8 +151,10 @@ class Indicator:
         self.no_effects = Gtk.CheckMenuItem(_("Show without effects"))
         self.no_effects.set_active(False)
         self.no_effects.set_use_underline(True)
+
         def _toggle_no_effects(widget=None):
             window.toggle_no_effects(self.no_effects.get_active())
+
         self.no_effects_handler_id = self.no_effects.connect("toggled", _toggle_no_effects)
         self.image_menu.append(self.no_effects)
 
@@ -153,12 +162,6 @@ class Indicator:
         self.google_image.connect("activate", window.google_image_search)
         self.image_menu.append(self.google_image)
 
-        self.image_menu.append(Gtk.SeparatorMenuItem.new())
-
-        self.publish_fb = Gtk.MenuItem(_("Share on Facebook"))
-        self.publish_fb.connect("activate", window.publish_on_facebook)
-        self.image_menu.append(self.publish_fb)
-
         self.rating_separator = Gtk.SeparatorMenuItem.new()
         self.image_menu.append(self.rating_separator)
 
@@ -170,14 +173,6 @@ class Indicator:
         # self.image_item.set_submenu(self.image_menu)
         # self.menu.append(self.image_item)
         #
-        self.sfw_menu = Gtk.Menu()
-        threading.Timer(2, self.populate_sfw_menu).start()
-
-        self.sfw_menu_item = Gtk.MenuItem(_("Report NSFW image"))
-        self.sfw_menu_item.set_sensitive(False)
-        self.sfw_menu_item.set_use_underline(True)
-        self.sfw_menu_item.set_submenu(self.sfw_menu)
-        self.menu.append(self.sfw_menu_item)
 
         self.quotes_menu = Gtk.Menu()
 
@@ -193,8 +188,10 @@ class Indicator:
 
         self.fast_forward_quote = Gtk.MenuItem(_("_Next, skipping forward history"))
         self.fast_forward_quote.set_use_underline(True)
+
         def _fast_forward_quote(widget):
             window.next_quote(widget, bypass_history=True)
+
         self.fast_forward_quote.connect("activate", _fast_forward_quote)
         self.quotes_menu.append(self.fast_forward_quote)
 
@@ -238,18 +235,15 @@ class Indicator:
         self.google_quote_author.connect("activate", window.google_quote_author)
         self.quotes_menu.append(self.google_quote_author)
 
-        self.quote_fb = Gtk.MenuItem(_("Share on Facebook"))
-        self.quote_fb.set_use_underline(True)
-        self.quote_fb.connect("activate", window.publish_quote_on_facebook)
-        self.quotes_menu.append(self.quote_fb)
-
         self.quotes_menu.append(Gtk.SeparatorMenuItem.new())
 
         self.quotes_preferences = Gtk.MenuItem(_("Preferences..."))
         self.quotes_preferences.set_use_underline(True)
+
         def _quotes_prefs(widget=None):
             window.preferences_dialog.ui.notebook.set_current_page(1)
             window.on_mnu_preferences_activate()
+
         self.quotes_preferences.connect("activate", _quotes_prefs)
         self.quotes_menu.append(self.quotes_preferences)
 
@@ -258,7 +252,6 @@ class Indicator:
         self.quotes_disable.connect("activate", window.disable_quotes)
         self.quotes_menu.append(self.quotes_disable)
 
-
         self.quotes = Gtk.MenuItem(_("_Quote"))
         self.quotes.set_use_underline(True)
         self.quotes.set_submenu(self.quotes_menu)
@@ -275,7 +268,9 @@ class Indicator:
         self.selector = Gtk.CheckMenuItem(_("_Wallpaper Selector"))
         self.selector.set_active(False)
         self.selector.set_use_underline(True)
-        self.selector_handler_id = self.selector.connect("toggled", window.show_hide_wallpaper_selector)
+        self.selector_handler_id = self.selector.connect(
+            "toggled", window.show_hide_wallpaper_selector
+        )
         self.menu.append(self.selector)
 
         self.downloads = Gtk.CheckMenuItem(_("Recent _Downloads"))
@@ -284,18 +279,17 @@ class Indicator:
         self.downloads_handler_id = self.downloads.connect("toggled", window.show_hide_downloads)
         self.menu.append(self.downloads)
 
-        try:
-            from varietyslideshow import varietyslideshow
-        except:
-            logger.warning('Variety Slideshow is not installed. This is an optional extension '
-                           'adding pan-and-zoom slideshows to Variety: see '
-                           'https://github.com/peterlevi/variety-slideshow for details')
-        else:
+        if Util.check_variety_slideshow_present():
             self.menu.append(Gtk.SeparatorMenuItem.new())
-
             self.slideshow = Gtk.MenuItem(_("Start Slideshow"))
             self.slideshow.connect("activate", window.on_start_slideshow)
             self.menu.append(self.slideshow)
+        else:
+            logger.warning(
+                "Variety Slideshow is not installed. This is an optional extension "
+                "adding pan-and-zoom slideshows to Variety: see "
+                "https://github.com/peterlevi/variety-slideshow for details"
+            )
 
         self.menu.append(Gtk.SeparatorMenuItem.new())
 
@@ -312,12 +306,13 @@ class Indicator:
         self.menu.append(self.donate)
 
         self.quit = Gtk.MenuItem(_("Quit"))
-        self.quit.connect("activate",window.on_quit)
+        self.quit.connect("activate", window.on_quit)
         self.menu.append(self.quit)
 
         self.menu.show_all()
 
     def create_indicator(self, window):
+        logger.info("indicator backend: %s", _indicator_backend)
         self.indicator = None
         self.status_icon = None
         self.visible = True
@@ -326,14 +321,23 @@ class Indicator:
             self.menu.popup(None, None, Gtk.StatusIcon.position_menu, self.status_icon, 0, time)
 
         def left_click_event(data):
-            self.menu.popup(None, None, Gtk.StatusIcon.position_menu, self.status_icon, 0, Gtk.get_current_event_time())
+            self.menu.popup(
+                None,
+                None,
+                Gtk.StatusIcon.position_menu,
+                self.status_icon,
+                0,
+                Gtk.get_current_event_time(),
+            )
 
         def on_indicator_scroll_status_icon(status_icon, event):
             window.on_indicator_scroll(None, 1, event.direction)
 
         icon_path = varietyconfig.get_data_file("media", "variety-indicator.png")
         if use_appindicator:
-            self.indicator = AppIndicator3.Indicator.new('variety', '', AppIndicator3.IndicatorCategory.APPLICATION_STATUS)
+            self.indicator = AppIndicator3.Indicator.new(
+                "variety", "", AppIndicator3.IndicatorCategory.APPLICATION_STATUS
+            )
             self.indicator.set_status(AppIndicator3.IndicatorStatus.ACTIVE)
             self.indicator.set_icon(icon_path)
             self.indicator.connect("scroll-event", window.on_indicator_scroll)
@@ -383,6 +387,14 @@ class Indicator:
                 return
             else:
                 icon_path = varietyconfig.get_data_file("media", "variety-indicator-dark.png")
+        elif icon in ["1", "2", "3", "4"]:
+            if Gtk.IconTheme.get_default().has_icon(THEME_ICON_NAME_NUM.format(icon)):
+                set_from_theme_icon(THEME_ICON_NAME_NUM.format(icon))
+                return
+            else:
+                icon_path = varietyconfig.get_data_file(
+                    "media", "variety-indicator-num{}.png".format(icon)
+                )
         elif icon and os.access(icon, os.R_OK) and Util.is_image(icon):
             icon_path = icon
         else:
@@ -398,54 +410,6 @@ class Indicator:
     def get_visible(self):
         return self.visible
 
-    def populate_sfw_menu(self):
-        try:
-            self.rating_items = []
-            sfw_ratings = Smart.get_all_sfw_ratings()
-
-            def _gui_update(sfw_ratings):
-                try:
-                    def _add_menuitem(rating):
-                        menuitem = Gtk.ImageMenuItem(_(rating['label_long']))
-                        menuitem.set_visible(True)
-
-                        def _rate(*args, **kwargs):
-                            self.parent.report_sfw_rating(file=None, rating=rating['rating'])
-
-                        menuitem.connect("activate", _rate)
-                        try:
-                            menuitem.set_always_show_image(True)
-                            image = Gtk.Image()
-                            image.set_from_file(varietyconfig.get_data_file("media", "sfw-%s.svg" % rating['rating']))
-                            menuitem.set_image(image)
-                        except:
-                            logger.exception(lambda: "Could not set image to NSFW menuitem:")
-                        self.sfw_menu.append(menuitem)
-                        self.rating_items.append(menuitem)
-
-                    map(_add_menuitem, reversed(sfw_ratings))
-
-                    separator = Gtk.SeparatorMenuItem.new()
-                    separator.set_visible(True)
-                    self.sfw_menu.append(separator)
-
-                    self.safe_mode = Gtk.CheckMenuItem(_("_Safe mode"))
-                    self.safe_mode.set_visible(True)
-                    self.safe_mode.set_active(self.parent.options.safe_mode)
-                    self.safe_mode.set_use_underline(True)
-                    self.safe_mode_handler_id = self.safe_mode.connect("toggled", self.parent.on_safe_mode_toggled)
-                    self.sfw_menu.append(self.safe_mode)
-
-                    self.sfw_menu_item.set_sensitive(True)
-
-                    self.parent.update_indicator()
-                except Exception:
-                    logger.exception(lambda: 'Oops, could not populate NSFW menu:')
-
-            Util.add_mainloop_task(_gui_update, sfw_ratings)
-        except Exception:
-            logger.exception(lambda: 'Oops, could not populate NSFW menu:')
-
 
 def new_application_indicator(window):
     ind = Indicator(window)
